@@ -124,18 +124,24 @@ class CreateCluster(command.Command):
             'cluster_template_id': parsed_args.cluster_template,
             'create_timeout': parsed_args.timeout,
             'discovery_url': parsed_args.discovery_url,
-            'docker_volume_size': parsed_args.docker_volume_size,
             'keypair': parsed_args.keypair,
             'master_count': parsed_args.master_count,
             'name': parsed_args.name,
             'node_count': parsed_args.node_count,
-            'master_flavor_id': parsed_args.master_flavor,
-            'flavor_id': parsed_args.flavor,
         }
 
         if parsed_args.labels is not None:
             args['labels'] = magnum_utils.handle_labels(parsed_args.labels)
 
+        if parsed_args.docker_volume_size is not None:
+            args['docker_volume_size'] = parsed_args.docker_volume_size
+
+        if parsed_args.master_flavor is not None:
+            args['master_flavor_id'] = parsed_args.master_flavor
+
+        if parsed_args.flavor is not None:
+            args['flavor_id'] = parsed_args.flavor
+
         cluster = mag_client.clusters.create(**args)
         print("Request to create cluster %s accepted"
               % cluster.uuid)
@@ -293,6 +299,12 @@ class ConfigCluster(command.Command):
             dest='force',
             default=False,
             help=_('Overwrite files if existing.'))
+        parser.add_argument(
+            '--output-certs',
+            action='store_true',
+            dest='output_certs',
+            default=False,
+            help=_('Output certificates in separate files.'))
 
         return parser
 
@@ -319,21 +331,23 @@ class ConfigCluster(command.Command):
             'cluster_uuid': cluster.uuid,
         }
 
+        tls = None
         if not cluster_template.tls_disabled:
             tls = magnum_utils.generate_csr_and_key()
             tls['ca'] = mag_client.certificates.get(**opts).pem
             opts['csr'] = tls['csr']
             tls['cert'] = mag_client.certificates.create(**opts).pem
-            for k in ('key', 'cert', 'ca'):
-                fname = "%s/%s.pem" % (parsed_args.dir, k)
-                if os.path.exists(fname) and not parsed_args.force:
-                    raise Exception("File %s exists, aborting." % fname)
-                else:
-                    f = open(fname, "w")
-                    f.write(tls[k])
-                    f.close()
+            if parsed_args.output_certs:
+                for k in ('key', 'cert', 'ca'):
+                    fname = "%s/%s.pem" % (parsed_args.dir, k)
+                    if os.path.exists(fname) and not parsed_args.force:
+                        raise Exception("File %s exists, aborting." % fname)
+                    else:
+                        with open(fname, "w") as f:
+                            f.write(tls[k])
 
         print(magnum_utils.config_cluster(cluster,
                                           cluster_template,
                                           parsed_args.dir,
-                                          force=parsed_args.force))
+                                          force=parsed_args.force,
+                                          certs=tls))
